summaryrefslogtreecommitdiffstats
path: root/src/compiler/shader_enums.h
diff options
context:
space:
mode:
authorKenneth Graunke <[email protected]>2016-07-07 02:02:38 -0700
committerKenneth Graunke <[email protected]>2016-07-17 19:26:48 -0700
commitac1181ffbef5250cb3b651e047cce5116727c34c (patch)
treeb6aa32932d99fa3dcb15d2435ff63b662b939488 /src/compiler/shader_enums.h
parente7d96e7685e911b91ce048c6639a4c290faf5d06 (diff)
compiler: Rename INTERP_QUALIFIER_* to INTERP_MODE_*.
Likewise, rename the enum type to glsl_interp_mode. Beyond the GLSL front-end, talking about "interpolation modes" seems more natural than "interpolation qualifiers" - in the IR, we're removed from how exactly the source language specifies how to interpolate an input. Also, SPIR-V calls these "decorations" rather than "qualifiers". Generated by: $ find . -regextype egrep -regex '.*\.(c|cpp|h)' -type f -exec sed -i \ -e 's/INTERP_QUALIFIER_/INTERP_MODE_/g' \ -e 's/glsl_interp_qualifier/glsl_interp_mode/g' {} \; Signed-off-by: Kenneth Graunke <[email protected]> Acked-by: Dave Airlie <[email protected]>
Diffstat (limited to 'src/compiler/shader_enums.h')
-rw-r--r--src/compiler/shader_enums.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/src/compiler/shader_enums.h b/src/compiler/shader_enums.h
index df3124eb6b3..a69905cb7d4 100644
--- a/src/compiler/shader_enums.h
+++ b/src/compiler/shader_enums.h
@@ -485,19 +485,19 @@ const char *gl_system_value_name(gl_system_value sysval);
* The possible interpolation qualifiers that can be applied to a fragment
* shader input in GLSL.
*
* Note: INTERP_QUALIFIER_NONE must be 0 so that memsetting the
* gl_fragment_program data structure to 0 causes the default behavior.
*/
-enum glsl_interp_qualifier
+enum glsl_interp_mode
{
- INTERP_QUALIFIER_NONE = 0,
- INTERP_QUALIFIER_SMOOTH,
- INTERP_QUALIFIER_FLAT,
- INTERP_QUALIFIER_NOPERSPECTIVE,
- INTERP_QUALIFIER_COUNT /**< Number of interpolation qualifiers */
+ INTERP_MODE_NONE = 0,
+ INTERP_MODE_SMOOTH,
+ INTERP_MODE_FLAT,
+ INTERP_MODE_NOPERSPECTIVE,
+ INTERP_MODE_COUNT /**< Number of interpolation qualifiers */
};
-const char *glsl_interp_qualifier_name(enum glsl_interp_qualifier qual);
+const char *glsl_interp_mode_name(enum glsl_interp_mode qual);
/**
* Fragment program results
@@ -485,19 +485,19 @@ const char *gl_system_value_name(gl_system_value sysval);
* shader input in GLSL.
*
- * Note: INTERP_QUALIFIER_NONE must be 0 so that memsetting the
+ * Note: INTERP_MODE_NONE must be 0 so that memsetting the
* gl_fragment_program data structure to 0 causes the default behavior.
*/